@@ -13,7 +13,7 @@ use namespace::autoclean;
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = '0.913';
+our $VERSION = '0.92';
 
 has client => (
     is       => 'ro',
@@ -223,16 +223,61 @@ sub register_project {
     my $self   = shift;
     my $sqitch = $self->sqitch;
     my $plan   = $sqitch->plan;
-    return try {
+    my $proj   = $plan->project;
+    my $uri    = $plan->uri;
+
+    my $res = $self->_dbh->selectcol_arrayref(
+        'SELECT uri FROM projects WHERE project = ?',
+        undef, $proj
+    );
+
+    if (@{ $res }) {
+        # A project with that name is already registreed. Compare URIs.
+        my $reg_uri = $res->[0];
+        if ( defined $uri && !defined $reg_uri ) {
+            hurl engine => __x(
+                'Cannot register "{project}" with URI {uri}: already exists with NULL URI',
+                project => $proj,
+                uri     => $uri
+            );
+        } elsif ( !defined $uri && defined $reg_uri ) {
+            hurl engine => __x(
+                'Cannot register "{project}" without URI: already exists with URI {uri}',
+                project => $proj,
+                uri     => $reg_uri
+            );
+        } elsif ( defined $uri && defined $reg_uri ) {
+            hurl engine => __x(
+                'Cannot register "{project}" with URI {uri}: already exists with URI {reg_uri}',
+                project => $proj,
+                uri     => $uri,
+                reg_uri => $reg_uri,
+            ) if $uri ne $reg_uri;
+        } else {
+            # Both are undef, so cool.
+        }
+    } else {
+        # Does the URI already exist?
+        my $res = $self->_dbh->selectcol_arrayref(
+            'SELECT project FROM projects WHERE uri = ?',
+            undef, $uri
+        );
+
+        hurl engine => __x(
+            'Cannot register "{project}" with URI {uri}: project "{reg_prog}" already using that URI',
+            project => $proj,
+            uri     => $uri,
+            reg_proj => $res->[0],
+        ) if @{ $res };
+
+        # Insert the project.
         $self->_dbh->do(q{
             INSERT INTO projects (project, uri, creator_name, creator_email)
             VALUES (?, ?, ?, ?)
-        }, undef, $plan->project, $plan->uri, $sqitch->user_name, $sqitch->user_email);
-        return $self;
-    } catch {
-        return $self if $DBI::state eq '23505'; # unique_violation
-        die $_;
-    };
+        }, undef, $proj, $uri, $sqitch->user_name, $sqitch->user_email);
+    }
+
+    return $self;
 }
 
 sub begin_work {
